@@ -215,7 +215,7 @@ as.data.frame.grates_year <- as.data.frame.vector
 
 is_nan_grates_year <- function(x) vector("logical", vec_size(x))
 
-is_finite_grates_year <- function(x) !vec_equal_na(x)
+is_finite_grates_year <- function(x) !vec_detect_missing(x)
 
 is_infinite_grates_year <- function(x) vector("logical", vec_size(x))
 
